# yut23_utils

[![PyPI - Version](https://img.shields.io/pypi/v/yut23-utils.svg)](https://pypi.org/project/yut23-utils)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/yut23-utils.svg)](https://pypi.org/project/yut23-utils)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install yut23-utils
```

## License

`yut23-utils` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
